@@ -25,8 +25,7 @@
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusObjectPath>
 #include "informationbox.h"
-#include "eniro.h"
-#include "connectionmanager.h"
+#include "source.h"
 
 class CallListener: public QObject
 {
@@ -35,14 +34,23 @@ class CallListener: public QObject
 public:
     CallListener();
     ~CallListener();
-    void begin();
+    bool begin();
     void end();
     static const int REQUEST_TIMEOUT = 10000;
     static const int BANNER_DELAY = 350;
-    static const int NUMBER_OF_RETRIES = 3;
+    static const int SEARCH_RETRIES = 2;
+    static const int CONNECT_RETRIES = 2;
+    static const int CONNECTION_LOOKUP_RETRIES = 8;
+    static const int GPRS_SCANS = 2;
+    static const int WLAN_SCANS = 5;
+    static const int WAIT_BETWEEN_RETRIES = 500;
+    static const int ERROR_BANNER_TIMEOUT = 4500;
+
+protected:
+    virtual void timerEvent(QTimerEvent* event);
 
 private slots:
-    void requestFinished(QVector <Eniro::Result> const& results, Eniro::SearchDetails const& details, bool error);
+    void requestFinished(QVector <Source::Result> const& results, Source::SearchDetails const& details, bool error);
     void incomingCall(QDBusObjectPath path, QString numbe);
     void callTerminate();
     void showTimedMessage();
@@ -50,15 +58,21 @@ private slots:
 private:
     Q_DISABLE_COPY(CallListener);
 
-    void search(Eniro::SearchDetails const& details);
+    void search(Source::SearchDetails const& details);
     void showResult(QString const& text);
     void showDelayedResult(QString const& text, int delay);
     void searchInit();
     void searchClose();
+    bool handleConnection();
+    void showError(QString const& msg, int delay = 0);
+    bool is3g();
+    void sleep(int ms);
+    void sendRetrySignal(QString const& iap, bool retry);
     QString createResult(QString const& name, QString const& street, QString const& city);
     QString timedMessage_;
-    Eniro* eniro_;
-    ConnectionManager* connectionManager_;
+    Source* source_;
+    Source::SourceId sourceId_;
+    QMap<QString, QString> sourceConfig_;
     bool closeConnection_;
     bool initialized_;
     InformationBox* box_;
@@ -66,7 +80,7 @@ private:
     static QDBusConnection systemBus_;
     int retries_;
     QString currentSearch_;
-    Eniro::Site site_;
+    int timer_;
 };
 
 #endif // CALLLISTENER_H
