@@ -16,16 +16,12 @@
  *
  */
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QTranslator>
-#include <QtCore/QLocale>
 #include <QtCore/QString>
-#include <QtCore/QList>
-#include <QDebug>
 #include <QtGui/QApplication>
 #include "calllistener.h"
 #include "settings.h"
 
+
 int main(int argc, char *argv[])
 {
     // If daemon was started on boot, the first parameter is set to "-boot"
@@ -40,13 +36,14 @@ int main(int argc, char *argv[])
 
     QApplication app(argc, argv);
 
-    QTranslator translator;
-    translator.load(":/translations/" + QLocale::system().name());
-    app.installTranslator(&translator);
+    Settings::instance()->loadLanguage(app);
 
     CallListener listener;
 
-    listener.begin();
+    if(!listener.begin())
+    {
+        return 1;
+    }
 
     return app.exec();
 
